@@ -4,8 +4,9 @@
 # Simple parser for ANSI C.  Based on the grammar in K&R, 2nd Ed.
 # -----------------------------------------------------------------------------
 
-import yacc
+import sys
 import clex
+import ply.yacc as yacc
 
 # Get the token map
 tokens = clex.tokens
