@@ -2,7 +2,10 @@
 #
 # Duplicated rule specifiers
 
-import lex
+import sys
+sys.path.insert(0,"..")
+
+import ply.lex as lex
 
 tokens = [
     "PLUS",
@@ -21,7 +24,6 @@ def t_NUMBER(t):
 def t_error(t):
     pass
 
-import sys
 sys.tracebacklimit = 0
 
 lex.lex()
