@@ -2,7 +2,10 @@
 #
 # tokens is right type, but is missing a token for one rule
 
-import lex
+import sys
+sys.path.insert(0,"..")
+
+import ply.lex as lex
 
 tokens = [
     "PLUS",
@@ -16,7 +19,7 @@ t_NUMBER = r'\d+'
 def t_error(t):
     pass
 
-import sys
+
 sys.tracebacklimit = 0
 
 lex.lex()
